@@ -5,7 +5,7 @@
 # Copyright (C) 2006 Knut Haugen <knuthaug at linpro.no>
 # Copyright (C) 2007-2009 Fredrik Andersen <fredrik.andersen at husbanken.no>
 # --
-# $Id: nb_NO.pm,v 1.83.2.5 2009/12/09 12:01:00 mb Exp $
+# $Id: nb_NO.pm,v 1.82 2009/07/13 09:49:47 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = q$Revision: 1.83.2.5 $;
+$VERSION = q$Revision: 1.82 $;
 
 sub Data {
     my $Self = shift;
@@ -28,7 +28,7 @@ sub Data {
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-1', 'iso-8859-15', ];
-    # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Year;)
+    # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
     $Self->{DateFormat}          = '%D/%M %Y %T';
     $Self->{DateFormatLong}      = '%A %D. %B %Y %T';
     $Self->{DateFormatShort}     = '%D.%M.%Y';
@@ -323,7 +323,6 @@ sub Data {
         'February' => 'februar',
         'March' => 'mars',
         'April' => 'april',
-        'May_long' => 'mai',
         'June' => 'juni',
         'July' => 'juli',
         'August' => 'august',
@@ -571,7 +570,7 @@ sub Data {
         'New ticket notification' => 'Merknad ved nyopprettet sak',
         'Send me a notification if there is a new ticket in "My Queues".' => 'Send meg en melding dersom det kommer en ny sak i mine utvalgte mapper.',
         'Follow up notification' => 'Oppflgingsmerknad',
-        'Send me a notification if a customer sends a follow up and I\'m the owner of the ticket or the ticket is unlocked and is in one of my subscribed queues.' => 'Send meg en melding ved kundekorrespondanse p saker jeg str som saksbehandler av.',
+        'Send me a notification if a customer sends a follow up and I\'m the owner of this ticket.' => 'Send meg en melding ved kundekorrespondanse p saker jeg str som saksbehandler av.',
         'Ticket lock timeout notification' => 'Melding ved overskridelse av tidsfrist for avslutting av sak',
         'Send me a notification if a ticket is unlocked by the system.' => 'Send meg en melding dersom systemet pner en avsluttet sak.',
         'Move notification' => 'Merknad ved mappe-endring',
@@ -717,7 +716,8 @@ sub Data {
 
         # Template: AdminEmail
         'Message sent to' => 'Melding sendt til',
-        'A message should have a subject!' => 'En melding m ha en emnebeskrivelse!',,
+        'A message should have a subject!' => 'En melding m ha en emnebeskrivelse!',
+        'Recipents' => 'Mottager(e)',
         'Recipients' => 'Mottager(e)',
         'Body' => 'Meldingstekst',
         'Send' => 'Send',
@@ -1123,10 +1123,10 @@ sub Data {
         # Template: AgentCustomerTableView
 
         # Template: AgentDashboard
-        'Dashboard' => 'Dashbord',
+        'Dashboard' => 'Dashboard',
 
         # Template: AgentDashboardCalendarOverview
-        'in' => 'om',
+        'in' => 'i',
 
         # Template: AgentDashboardImage
 
@@ -1324,7 +1324,6 @@ sub Data {
         'Ticket Merge' => 'Flett saker',
 
         # Template: AgentTicketMove
-        'If you want to account time, please provide Subject and Text!' => '',
         'Move Ticket' => 'Flytt sak',
 
         # Template: AgentTicketNote
@@ -1712,8 +1711,6 @@ sub Data {
         'Ticket Status View' => 'Sakstatus-visning',
         'Modified' => 'Endret',
         'Ticket selected for bulk action!' => 'Sak valgt for masseredigering',
-        '%s is not writable!' => '%s er ikke skrivbar!',
-        'Cannot create %s!' => 'Kan ikke opprette %s!',
     };
     # $$STOP$$
     return;
